@@ -1,4 +1,4 @@
-/* $Id: procmem.h,v 1.23 2004/12/06 14:44:10 bdejean Exp $ */
+/* $Id: procmem.h,v 1.24 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -55,7 +55,7 @@ struct _glibtop_proc_mem
 				 * of the process; usually 2,147,483,647 */
 };
 
-#define glibtop_get_proc_mem(p1, p2)	glibtop_get_proc_mem_l(glibtop_global_server, p1, p2)
+void glibtop_get_proc_mem(glibtop_proc_mem *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_MEM
 #define glibtop_get_proc_mem_r		glibtop_get_proc_mem_p
