@@ -1,4 +1,4 @@
-/* $Id: procsignal.h,v 1.25 2003/10/20 20:11:58 hadess Exp $ */
+/* $Id: procsignal.h,v 1.27 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -49,7 +49,7 @@ struct _glibtop_proc_signal
 		sigcatch [2];		/* mask of caught  signals */
 };
 
-#define glibtop_get_proc_signal(p1, p2)	glibtop_get_proc_signal_l(glibtop_global_server, p1, p2)
+void glibtop_get_proc_signal(glibtop_proc_signal *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_SIGNAL
 #define glibtop_get_proc_signal_r	glibtop_get_proc_signal_p
@@ -67,16 +67,6 @@ void glibtop_init_proc_signal_s (glibtop *server);
 void glibtop_get_proc_signal_s (glibtop *server, glibtop_proc_signal *buf, pid_t pid);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_proc_signal [];
-extern const unsigned glibtop_types_proc_signal [];
-extern const char *glibtop_labels_proc_signal [];
-extern const char *glibtop_descriptions_proc_signal [];
-
-#endif
 
 G_END_DECLS
 
