@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: shm_limits.c,v 1.21 2005/12/12 09:38:11 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/shm_limits.h>
@@ -32,28 +31,23 @@
 #if defined(__bsdi__) && (_BSDI_VERSION < 199700)
 /* Older versions of BSDI don't seem to have this. */
 
-int
+void
 glibtop_init_shm_limits_p (glibtop *server)
-{
+{ }
 
-    return 0;
-}
-
-int
+void
 glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
 {
-    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SHM_LIMITS), 0);
+        glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SHM_LIMITS), 0);
 
-    memset (buf, 0, sizeof (glibtop_shm_limits));
-
-    return 0;
+        memset (buf, 0, sizeof (glibtop_shm_limits));
 }
 
 #else
 
 /* #define KERNEL to get declaration of `struct shminfo'. */
 
-#if defined(__FreeBSD__)  || defined(__bsdi__)
+#if (defined(__FreeBSD__) && (__FreeBSD_version < 410000)) || defined(__bsdi__)
 #define KERNEL 1
 #else
 #define _KERNEL 1
@@ -63,63 +57,59 @@ glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
 #include <sys/shm.h>
 
 static unsigned long _glibtop_sysdeps_shm_limits =
-(1L << GLIBTOP_SHM_LIMITS_SHMMAX) + (1L << GLIBTOP_SHM_LIMITS_SHMMIN) +
-(1L << GLIBTOP_SHM_LIMITS_SHMMNI) + (1L << GLIBTOP_SHM_LIMITS_SHMSEG) +
-(1L << GLIBTOP_SHM_LIMITS_SHMALL);
+(1L << GLIBTOP_IPC_SHMMAX) + (1L << GLIBTOP_IPC_SHMMIN) +
+(1L << GLIBTOP_IPC_SHMMNI) + (1L << GLIBTOP_IPC_SHMSEG) +
+(1L << GLIBTOP_IPC_SHMALL);
 
 /* The values in this structure never change at runtime, so we only
  * read it once during initialization. We have to use the name `_shminfo'
  * since `shminfo' is already declared external in <sys/shm.h>. */
 static struct shminfo _shminfo;
-  
+
 /* nlist structure for kernel access */
 static struct nlist nlst [] = {
-    { "_shminfo" },
-    { 0 }
+	{ "_shminfo" },
+	{ 0 }
 };
 
 /* Init function. */
 
-int
+void
 glibtop_init_shm_limits_p (glibtop *server)
 {
-    if (kvm_nlist (server->_priv->machine.kd, nlst) < 0) {
-	glibtop_warn_io_r (server, "kvm_nlist (shm_limits)");
-	return -1;
-    }
-	
-    if (kvm_read (server->_priv->machine.kd, nlst [0].n_value,
-		  &_shminfo, sizeof (_shminfo)) != sizeof (_shminfo)) {
-	glibtop_warn_io_r (server, "kvm_read (shminfo)");
-	return -1;
-    }
+	if (kvm_nlist (server->machine.kd, nlst) < 0) {
+		glibtop_warn_io_r (server, "kvm_nlist (shm_limits)");
+		return;
+	}
 
-    server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
+	if (kvm_read (server->machine.kd, nlst [0].n_value,
+		      &_shminfo, sizeof (_shminfo)) != sizeof (_shminfo)) {
+		glibtop_warn_io_r (server, "kvm_read (shminfo)");
+		return;
+	}
 
-    return 0;
+	server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
 }
 
 /* Provides information about sysv ipc limits. */
 
-int
+void
 glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
 {
-    glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SHM_LIMITS), 0);
-	
-    memset (buf, 0, sizeof (glibtop_shm_limits));
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SHM_LIMITS), 0);
 
-    if (server->sysdeps.shm_limits == 0)
-	return -1;
+	memset (buf, 0, sizeof (glibtop_shm_limits));
 
-    buf->shmmax = _shminfo.shmmax;
-    buf->shmmin = _shminfo.shmmin;
-    buf->shmmni = _shminfo.shmmni;
-    buf->shmseg = _shminfo.shmseg;
-    buf->shmall = _shminfo.shmall;
+	if (server->sysdeps.shm_limits == 0)
+		return;
 
-    buf->flags = _glibtop_sysdeps_shm_limits;
+	buf->shmmax = _shminfo.shmmax;
+	buf->shmmin = _shminfo.shmmin;
+	buf->shmmni = _shminfo.shmmni;
+	buf->shmseg = _shminfo.shmseg;
+	buf->shmall = _shminfo.shmall;
 
-    return 0;
+	buf->flags = _glibtop_sysdeps_shm_limits;
 }
 
 #endif /* either a newer BSDI or no BSDI at all. */
